==> amqp-client-1.6.0-sources.jar: com/rabbitmq/utility/BlockingValueOrException.java <==
//   The contents of this file are subject to the Mozilla Public License
//   Version 1.1 (the "License"); you may not use this file except in
//   compliance with the License. You may obtain a copy of the License at
//   http://www.mozilla.org/MPL/
//
//   Software distributed under the License is distributed on an "AS IS"
//   basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
//   License for the specific language governing rights and limitations
//   under the License.
//
//   The Original Code is RabbitMQ.
//
//   The Initial Developers of the Original Code are LShift Ltd,
//   Cohesive Financial Technologies LLC, and Rabbit Technologies Ltd.
//
//   Portions created before 22-Nov-2008 00:00:00 GMT by LShift Ltd,
//   Cohesive Financial Technologies LLC, or Rabbit Technologies Ltd
//   are Copyright (C) 2007-2008 LShift Ltd, Cohesive Financial
//   Technologies LLC, and Rabbit Technologies Ltd.
//
//   Portions created by LShift Ltd are Copyright (C) 2007-2009 LShift
//   Ltd. Portions created by Cohesive Financial Technologies LLC are
//   Copyright (C) 2007-2009 Cohesive Financial Technologies
//   LLC. Portions created by Rabbit Technologies Ltd are Copyright
//   (C) 2007-2009 Rabbit Technologies Ltd.
//
//   All Rights Reserved.
//
//   Contributor(s): ______________________________________.
//
package com.rabbitmq.utility;

import java.util.concurrent.TimeoutException;

public class BlockingValueOrException<V, E extends Throwable>
    extends BlockingCell<ValueOrException<V, E>>
{
    public void setValue(V v) {
        super.set(ValueOrException.<V, E>makeValue(v));
    }

    public void setException(E e) {
        super.set(ValueOrException.<V, E>makeException(e));
    }

    public V uninterruptibleGetValue() throws E {
        return uninterruptibleGet().getValue();
    }
    
    public V uninterruptibleGetValue(int timeout) throws E, TimeoutException {
    	return uninterruptibleGet(timeout).getValue();
    }
}

==> amqp-client-2.2.0-sources.jar: com/rabbitmq/utility/BlockingValueOrException.java <==
//   The contents of this file are subject to the Mozilla Public License
//   Version 1.1 (the "License"); you may not use this file except in
//   compliance with the License. You may obtain a copy of the License at
//   http://www.mozilla.org/MPL/
//
//   Software distributed under the License is distributed on an "AS IS"
//   basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
//   License for the specific language governing rights and limitations
//   under the License.
//
//   The Original Code is RabbitMQ.
//
//   The Initial Developers of the Original Code are LShift Ltd,
//   Cohesive Financial Technologies LLC, and Rabbit Technologies Ltd.
//
//   Portions created before 22-Nov-2008 00:00:00 GMT by LShift Ltd,
//   Cohesive Financial Technologies LLC, or Rabbit Technologies Ltd
//   are Copyright (C) 2007-2008 LShift Ltd, Cohesive Financial
//   Technologies LLC, and Rabbit Technologies Ltd.
//
//   Portions created by LShift Ltd are Copyright (C) 2007-2010 LShift
//   Ltd. Portions created by Cohesive Financial Technologies LLC are
//   Copyright (C) 2007-2010 Cohesive Financial Technologies
//   LLC. Portions created by Rabbit Technologies Ltd are Copyright
//   (C) 2007-2010 Rabbit Technologies Ltd.
//
//   All Rights Reserved.
//
//   Contributor(s): ______________________________________.
//
package com.rabbitmq.utility;

import java.util.concurrent.TimeoutException;

public class BlockingValueOrException<V, E extends Throwable & SensibleClone<E>>
    extends BlockingCell<ValueOrException<V, E>>
{
    public void setValue(V v) {
        super.set(ValueOrException.<V, E>makeValue(v));
    }

    public void setException(E e) {
        super.set(ValueOrException.<V, E>makeException(e));
    }

    public V uninterruptibleGetValue() throws E {
        return uninterruptibleGet().getValue();
    }

    public V uninterruptibleGetValue(int timeout) throws E, TimeoutException {
    	return uninterruptibleGet(timeout).getValue();
    }
}
